Documentation
¶
Overview ¶
Package runner provides a parallel execution engine for multi-repo git operations.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OpFunc ¶
type OpFunc func(repo *db.Repository) (message string, skipReason string, err error)
OpFunc is the function signature for a repository operation. Return (message, skip reason, error). If skipReason != "" the result is Skipped.
Click to show internal directories.
Click to hide internal directories.